@@ -382,6 +382,8 @@ void release_file_oplock(files_struct *fsp)
 
   fsp->oplock_type = NO_OPLOCK;
   fsp->sent_oplock_break = NO_BREAK_SENT;
+
+  flush_write_cache(fsp, OPLOCK_RELEASE_FLUSH);
 }
 
 /****************************************************************************
@@ -1312,7 +1314,7 @@ BOOL attempt_close_oplocked_file(files_struct *fsp)
     /* Try and break the oplock. */
     file_fd_struct *fd_ptr = fsp->fd_ptr;
     if(oplock_break( fd_ptr->dev, fd_ptr->inode, &fsp->open_time, True)) {
-      if(!fsp->open) /* Did the oplock break close the file ? */
+      if(file_find_fsp(fsp) == NULL) /* Did the oplock break close the file ? */
         return True;
     }
   }
