@@ -33,15 +33,14 @@ setup the shared area
 void smbw_setup_shared(void)
 {
 	int fd;
-	pstring s, name;
+	pstring name;
 
-	slprintf(s,sizeof(s)-1, "%s/smbw.XXXXXX",tmpdir());
+	slprintf(name,sizeof(name)-1, "%s/smbw.XXXXXX",tmpdir());
 
-	fstrcpy(name,(char *)smbd_mktemp(s));
+	fd = smb_mkstemp(name);
 
-	/* note zero permissions! don't change this */
-	fd = sys_open(name,O_RDWR|O_CREAT|O_TRUNC|O_EXCL,0); 
 	if (fd == -1) goto failed;
+
 	unlink(name);
 
 	shared_fd = set_maxfiles(SMBW_MAX_OPEN);
@@ -54,9 +53,9 @@ void smbw_setup_shared(void)
 
 	DEBUG(4,("created shared_fd=%d\n", shared_fd));
 
-	slprintf(s,sizeof(s)-1,"%d", shared_fd);
+	slprintf(name,sizeof(name)-1,"%d", shared_fd);
 
-	smbw_setenv("SMBW_HANDLE", s);
+	smbw_setenv("SMBW_HANDLE", name);
 
 	return;
 
